///////////////////////////////////////////////////////////////////////////////
//
//  File Name 
//      DIRMON.H
//
//  Description
//      This file defines constants, function prototypes, and data types
//      for the Directory Monitor sample.
//
//  Author
//      Irving De la Cruz (irvingd@microsoft.com)
//
//  Revision: 1.1
//
// Written for Microsoft Corporation
// Copyright (c) 1996-1997 Microsoft Corporation. All rights reserved.
//
#ifndef _DIRMON_H
#define _DIRMON_H

#define STRICT
#define _WIN32_WINNT 0x0400
#include <WINDOWS.H>
#include <MAPIX.H>
#include <MAPIUTIL.H>

#include "RESOURCE.H"
#include "EVENTMSG.H"

// Executable name and service name strings
#define DIRMON_SERVICE_NAME_SHORT       "DirMonSampleService"
#define DIRMON_SERVICE_NAME             "Sample Directory Monitor"
#define DIRMON_EVENTLOG_SOURCE          DIRMON_SERVICE_NAME_SHORT
#define DIRMON_SERVICE_EXE              "DIRMON.EXE"
#define DIRMON_SERVICE_EXE_PATH         "\\" DIRMON_SERVICE_EXE

// Registry keys for configuration
#define REGKEY_DIRMON_SERVICE_CONFIG    "SYSTEM\\CurrentControlSet\\Services\\" DIRMON_SERVICE_NAME_SHORT "\\Config"
#define REGKEY_CONFIG_PROFILE           "MAPI Logon Profile"
#define REGKEY_CONFIG_MONDIR            "Monitored Directory"

// Command line options
#define CMDLINE_RUN_AS_SERVICE          "/RUN_AS_SERVICE"
#define CMDLINE_APP                     "/APP"
#define CMDLINE_INSTALL                 "/INSTALL"
#define CMDLINE_INSTALL_ACCOUNT         "/ACCOUNT="
#define CMDLINE_INSTALL_PASSWORD        "/PASSWORD="
#define CMDLINE_INSTALL_PROFILE         "/PROFILE="
#define CMDLINE_INSTALL_DIRECTORY       "/DIRECTORY="
#define CMDLINE_REMOVE                  "/REMOVE"
#define CMDLINE_HELP                    "/HELP"
#define CMDLINE_HELP_ALT_1              "/?"
#define CMDLINE_HELP_ALT_2              "?"

// Custom data structures
typedef struct DIRMON_CONFIG
{
    char szMAPIProfile[64];         // Loging profile
    char szMonitorDir[MAX_PATH];    // Watched directory
} DIRMON_CONFIG;

// Function prototypes
HRESULT WINAPI InitMAPISession
                (BOOL                       fIsNTService,
                 LPSTR                      pszProfileName);
void WINAPI FinishMAPISession
                ();
BOOL CALLBACK ServiceDlgProc
                (HWND                       hDlg,
                 UINT                       message,
                 WPARAM                     wParam,
                 LPARAM                     lParam);
HRESULT WINAPI InitializeService
                (HWND                       hListBox);
HRESULT WINAPI OpenExchangePFStore
                ();
HRESULT WINAPI StartDirectoryWatch
                ();
void WINAPI FinishDirectoryWatch
                ();
void WINAPI PostPFMessage
                (PFILE_NOTIFY_INFORMATION   pFNI);
void DirMonServiceCtrlHandler
                (DWORD                      dwControlCode);
DWORD WINAPI SendStatusToSCM
                (DWORD                      dwServiceState,
                 DWORD                      dwError,
                 DWORD                      dwCheckPoint,
                 DWORD                      dwWait);
void DirMonServiceMain
                (DWORD                      dwArgc,
                 LPTSTR *                   pszArgv);
DWORD WINAPI TerminateService
                (DWORD                      dwError,
                 BOOL                       fRunAsService = TRUE);
DWORD WINAPI ServiceWaitOnEvent
                (HANDLE                     hEvent);
DWORD WINAPI InstallService
                (LPSTR                      szFullPathToServiceExe,
                 LPSTR                      szServiceName,
                 LPSTR                      szServiceNameShort,
                 LPSTR                      szAccount,
                 LPSTR                      szPassword);
DWORD WINAPI RemoveService
                (LPSTR                      szServiceNameShort);
DWORD WINAPI AddConfigRegistryValues
                (LPSTR                      pszMAPIProfile,
                 LPSTR                      pszMonitoredDir);
DWORD WINAPI AddEventLogSource
                (LPSTR                      szServiceEXE);
DWORD WINAPI RemoveEventLogSource
                ();
DWORD WINAPI LoadServiceSettings
                ();
DWORD WINAPI AddUserToLocalGroup
                (LPSTR                      pszAccountName,
                 LPSTR                      pszLocalGroup);
DWORD WINAPI SetRequiredPrivileges
                (LPSTR                      pszUserAccount);

DWORD WINAPI InitEventLog
                ();
void WINAPI UnInitEventLog
                ();
void WINAPI LogEvent
                (BOOL                       fError,
                 DWORD                      dwEventID,
                 DWORD                      dwData = 0,
                 LPSTR *                    rgszMsgs = NULL,
                 WORD                       wCount = 0,
                 HRESULT                    hResult = S_OK);
inline void WINAPI LogEvent
                (BOOL                       fError,
                 DWORD                      dwEventID,
                 HRESULT                    hResult)
{
    LogEvent (fError, dwEventID, 0, NULL, 0, hResult);
}
inline void WINAPI LogEvent
                (BOOL                       fError,
                 DWORD                      dwEventID,
                 LPSTR                      szString)
{
    LPSTR szStrList[] = { szString };
    LogEvent (fError, dwEventID, 0, szStrList, 1);
}

// Global variables used in the different source code files
extern LPMAPISESSION            g_pSession;
extern LPMDB                    g_pMDB;
extern LPMAPIFOLDER             g_pFolder;
extern SBinary                  g_IdentityEID;
extern SERVICE_STATUS_HANDLE    g_ssHandle;
extern HANDLE                   g_hTerminateEvent;
extern DIRMON_CONFIG            g_Config;

#endif // _DIRMON_H

// End of file for DIRMON.H
